<?php
class rex_bx_slider {
	
	// Flag to load jQuery Plugin
	public $loadEasingPlugin = FALSE;
	
	// Flag to load bxVideo Plugin
	public $loadVideoPlugin = FALSE;
	
	// Config Store
	private $configs = array();
	
	private $inlineScripts = array();
	
	// Do not change these defaults (that are bxSlider defaults)
	private $defaults = array(
		'mode' => 'horizontal',
		'easing' => NULL,
		'useCSS' => true,
		'speed' => 500,
		'responsive' => true,
		'preloadImages' => 'visible',
		'slideWidth' => 0,
		'slideMargin' => 0,
		'startSlide' => 0,
		'randomStart' => false,
		'infiniteLoop' => true,
		'captions' => false,
		'ticker' => false,
		'tickerHover' => false,
		'auto' => false,
		'pause' => 4000,
		'autoStart' => true,
		'autoDirection' => 'next',
		'autoHover' => false,
		'autoDelay' => 0,
		'autoControls' => false,
		'autoControlsCombine' => false,
		'hideControlOnEnd' => false,
		'minSlides' => 1,
		'maxSlides' => 1,
		'moveSlides' => 0,
		'pager' => true,
		'pagerType' => 'full',
		'pagerShortSeparator' => ' / ',
		'controls' => true,
		'nextText' => 'Next',
		'prevText' => 'Prev'
	);
	
	/**
	 * Sets configs for a bxSlider
	 * @param int $id
	 * @param string $config (json string)
	 */
	public function setConfig($id, $config) {
		$this->configs[$id] = json_decode(htmlspecialchars_decode($config), TRUE);
		if (isset($this->configs[$id]['useCSS']) && $this->configs[$id]['useCSS'] === FALSE) {
			$this->loadEasingPlugin = TRUE;
		}
		if (isset($this->configs[$id]['video']) && $this->configs[$id]['video'] === TRUE) {
			$this->loadVideoPlugin = TRUE;
		}
	}
	
	public function setInlineScripts($js = '') {
		$this->inlineScripts[] = $js;
	}
	
	/**
	 * Return config default json
	 * @return json string
	 */
	public function getConfigDefaultsAsJson(){
		$searchFor = array('{', ',', ':', '}');
		$replaceWith = array("{\n\t", ",\n\t", ": ", "\n}");
		$json = str_replace($searchFor, $replaceWith, json_encode($this->defaults));
		return stripcslashes($json);
	}
	
	/**
	 * Removes all bxSlider default settings
	 * @param json $config
	 * @return type
	 */
	public function removeDefaults($config){
		foreach($config as $key => $value) {
			
			if (isset($this->defaults[$key]) === FALSE && $this->defaults[$key] !== NULL) {
				continue;
			}
			
			// Remove Backslashes
			if (is_string($value)) {
				$value = stripslashes($value);
			}

			// Remove defaults and cast to null
			if ($this->defaults[$key] === $value) {
				unset($config[$key]);
			} else if ($this->defaults[$key] === NULL && $value === '') {
				unset($config[$key]);
			}

		}
		return $config;
	}

		/**
	 * Returns bxSlider configs as javascript
	 * @param array $params
	 * @return string $script
	 */
	public function getConfigInitScript(){
		$configs = $this->configs;
		$js  = '<script>' . PHP_EOL;
		$js .= '$(document).ready(function(){' . PHP_EOL;
		
		// Each Slideshow
		foreach($configs as $id => $config) {
			$config = ($this->removeDefaults($config));
			$js .= '$("#bx-slideshow-' . $id .'").bxSlider(';
			$js .= json_encode($config);	
			$js .= ');' . PHP_EOL;
		}
		
		// Inline scripts
		if (count($this->inlineScripts)) {
			$js .= implode("\n", $this->inlineScripts) . "\n";
		}
		$js .= '});' . PHP_EOL;
		$js .= '</script>' . PHP_EOL;
		return $js;
	}
}